@@ -1,7 +1,7 @@
 package Bencher::Scenario::BigFloat;
 
 our $DATE = '2017-01-25'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -42,7 +42,7 @@ Bencher::Scenario::BigFloat - Benchmark arbitrary size floating point arithmetic
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::BigFloat (from Perl distribution Bencher-Scenario-BigFloat), released on 2017-01-25.
+This document describes version 0.03 of Bencher::Scenario::BigFloat (from Perl distribution Bencher-Scenario-BigFloat), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -105,13 +105,13 @@ Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2
 Benchmark with default options (C<< bencher -m BigFloat >>):
 
  #table1#
- +-------------------+---------------+-----------+-------------+------------+----------+---------+
- | participant       | dataset       | rate (/s) | time (ms)   | vs_slowest |  errors  | samples |
- +-------------------+---------------+-----------+-------------+------------+----------+---------+
- | 1k-Math::BigFloat | 100dec_digits |       5.4 | 180         |       1    |   0.0013 |      20 |
- | 1k-Math::BigFloat | 0dec_digits   |       6.6 | 151         |       1.22 | 8.5e-05  |      20 |
- | 1k-native         | 0dec_digits   |   28826.9 |   0.0346898 |    5326    | 1.1e-11  |      20 |
- +-------------------+---------------+-----------+-------------+------------+----------+---------+
+ +-------------------+---------------+-----------+-------------+------------+-----------+---------+
+ | participant       | dataset       | rate (/s) | time (ms)   | vs_slowest |  errors   | samples |
+ +-------------------+---------------+-----------+-------------+------------+-----------+---------+
+ | 1k-Math::BigFloat | 100dec_digits |      5.6  | 180         |       1    |   0.00028 |      21 |
+ | 1k-Math::BigFloat | 0dec_digits   |      6.54 | 153         |       1.17 |   0.00011 |      21 |
+ | 1k-native         | 0dec_digits   |  28828.2  |   0.0346883 |    5145.26 | 1.1e-11   |      20 |
+ +-------------------+---------------+-----------+-------------+------------+-----------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m BigFloat --module-startup >>):
@@ -120,8 +120,8 @@ Benchmark module startup overhead (C<< bencher -m BigFloat --module-startup >>):
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
  | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
- | Math::BigFloat      | 0.83                         | 4.1                | 16             |      44   |                   39.7 |          1 |   0.00013 |      20 |
- | perl -e1 (baseline) | 6.3                          | 10                 | 21             |       4.3 |                    0   |         10 | 2.7e-05   |      20 |
+ | Math::BigFloat      | 0.82                         | 4.1                | 16             |      46   |                   40.3 |          1 |   0.00012 |      21 |
+ | perl -e1 (baseline) | 6.3                          | 9.9                | 21             |       5.7 |                    0   |          8 | 1.3e-05   |      20 |
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
 
 
