@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::BigFloat;
 
-our $VERSION = 0.02; # VERSION
+our $VERSION = 0.03; # VERSION
 
 our $results = [
   [
@@ -9,30 +9,30 @@ our $results = [
     [
       {
         dataset     => "100dec_digits",
-        errors      => 0.0013,
+        errors      => 0.00028,
         participant => "1k-Math::BigFloat",
-        rate        => 5.4,
-        samples     => 20,
+        rate        => 5.6,
+        samples     => 21,
         time        => 180,
         vs_slowest  => 1,
       },
       {
         dataset     => "0dec_digits",
-        errors      => 8.5e-05,
+        errors      => 0.00011,
         participant => "1k-Math::BigFloat",
-        rate        => 6.6,
-        samples     => 20,
-        time        => 151,
-        vs_slowest  => 1.22,
+        rate        => 6.54,
+        samples     => 21,
+        time        => 153,
+        vs_slowest  => 1.17,
       },
       {
         dataset     => "0dec_digits",
         errors      => 1.1e-11,
         participant => "1k-native",
-        rate        => 28826.9,
+        rate        => 28828.2,
         samples     => 20,
-        time        => 0.0346898,
-        vs_slowest  => 5326,
+        time        => 0.0346883,
+        vs_slowest  => 5145.26,
       },
     ],
     {
@@ -155,7 +155,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2756.796,
+                                              speed                        => 2842.109,
                                               stepping                     => 4,
                                             },
                                             {
@@ -270,7 +270,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2773.914,
+                                              speed                        => 2681.929,
                                               stepping                     => 4,
                                             },
                                             {
@@ -385,7 +385,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2816.406,
+                                              speed                        => 2879.078,
                                               stepping                     => 4,
                                             },
                                             {
@@ -500,13 +500,14 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2616.687,
+                                              speed                        => 2880.773,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 8.89489006996155,
+      "func.elapsed_time"              => 8.98622989654541,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
+                                            "__PACKAGE__" => 1.034,
                                             "Bencher::Scenario::BigFloat" => undef,
                                             "Benchmark::Dumb" => "0.10",
                                             "Devel::Platform::Info" => 0.16,
@@ -545,9 +546,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1485313846,
       "func.scenario_module_sha1sum"   => "75a18cd2438015f84d31ae0896a4889508b858a0",
       "func.scenario_module_sha256sum" => "e3da277b991820f239da9a2efde3107eac34d342a0ca58a8c9177d0f0f9caefe",
-      "func.time_end"                  => 1485313983.25588,
+      "func.time_end"                  => 1485317335.82727,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1485313974.36099,
+      "func.time_start"                => 1485317326.84104,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
